(v0.12.6)=
### 0.12.6 {small}`2025-11-06`

#### Bug fixes

- Attach {class}`h5py.File` object to {class}`~anndata.AnnData` at the `file` attribute returned from  {func}`~anndata.experimental.read_lazy` {user}`ilan-gold` ({pr}`2204`)
